@@ -1,5 +1,10 @@
 from .base import BaseSimdakPaud
-from .jenis_penggunaan import JENIS_KOMPONEN, JENIS_PENGGUNAAN, PENGGUNAAN
+from .jenis_penggunaan import (
+    JENIS_KOMPONEN,
+    JENIS_PENGGUNAAN,
+    PENGGUNAAN,
+    get_key,
+)
 from .rkas import RkasData, Rkas, RkasPaud
 from .paud import SimdakPaud
 from .excel import exports, imports
